#
# spec file for package python3-jedi
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-jedi
Version:        0.9.0
Release:        5.1
Summary:        An autocompletion tool for Python
License:        MIT
Group:          Development/Languages/Python
Url:            https://jedi.readthedocs.org/en/latest/index.html
Source0:        https://pypi.python.org/packages/source/j/jedi/jedi-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-docopt
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
Requires:       python3-docopt
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Jedi is an autocompletion tool for Python. It works. With and without syntax
errors. Sometimes it sucks, but that's normal in dynamic languages. But it
sucks less than other tools. It understands almost all of the basic Python
syntax elements including many builtins.

Jedi suports two different goto functions and has support for renaming.
Probably it will also have some support for refactoring in the future.

Jedi uses a very simple interface to connect with IDE's. As an reference, there
is a VIM implementation, which uses Jedi's autocompletion. However, I encourage
you to use Jedi in your IDEs. Start writing plugins! If there are problems with
licensing, just contact me.

%prep
%setup -q -n jedi-%{version}
# fix unicode issues
sed -i "s/).read()/, encoding='utf-8').read()/g" setup.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
rm -rf build

%check
# fix unicode issues
sed -i "s/open(path).read()/open(path, encoding='utf-8').read()/g" test/run.py
# disable clean_jedi_cache fixture which, in newer pytest, breaks doctests
sed -i "/clean_jedi_cache/d" pytest.ini
# we don't care about the speed, just that it works
# skip failing import tests on 0.9.0
py.test -k "not test_speed" --ignore=test/test_integration_import.py

%files
%defattr(0644,root,root,0755)
%doc AUTHORS.txt CHANGELOG.rst README.rst LICENSE.txt
%{python3_sitelib}/*

%changelog
* Mon Jul 10 2017 jmatejek@suse.com
- disable clean_jedi_cache test fixture (fixes bsc#1047831)
* Wed May  6 2015 benoit.monin@gmx.fr
- update to version 0.9.0:
  * The import logic has been rewritten to look more like Python's.
    There is now an Evaluator.modules import cache, which resembles
    sys.modules.
  * Integrated the parser of 2to3. This will make refactoring
    possible. It will also be possible to check for error messages
    (like compiling an AST would give) in the future.
  * With the new parser, the evaluation also completely changed.
    It's now simpler and more readable.
  * Completely rewritten REPL completion.
  * Added jedi.names, a command to do static analysis. Thanks to
    that sourcegraph guys for sponsoring this!
  * Alpha version of the linter.
- remove "-final0" appended to source version
- add python-unittest2 as a test dependency for SLE11
- skip failing tests in test_integration_import.py
* Wed Aug 13 2014 toddrme2178@gmail.com
- Update to version 0.8.1
  * Bugfix release, the last release forgot to include files that
    improve autocompletion for builtin libraries. Fixed.
- Update to version 0.8.0
  * Memory Consumption for compiled modules (e.g. builtins, sys)
    has been reduced drastically. Loading times are down as well
    (it takes basically as long as an import).
  * REPL completion is starting to become usable.
  * Various small API changes. Generally this released focuses on
    stability and refactoring of internal APIs.
  * Introducing operator precedence, which makes calculating
    correct Array indices and __getattr__ strings possible.
- Update to version 0.7.0
  * switched from LGPL to MIT license
  * added an Interpreter class to the API to make autocompletion
    in REPL possible.
  * added autocompletion support for namespace packages
  * add sith.py, a new random testing method
- Change License to MIT
- Drop old python2 stuff
* Thu Aug 15 2013 mvyskocil@suse.com
- update to 0.6.0
  * Created find_module helper to handle compatibility with python 3.3
  * Fixed caching issues
  * More robust source encoding detection
  * Improved documentantion
  * and lot of bugfixes
- drop pre-checkin.sh
- drop a dependency on rpmbuild > 4.10, we don't need no ~ in version
* Thu May  9 2013 mvyskocil@suse.com
- package python3 variant via pre_checkin.sh
* Thu May  2 2013 mvyskocil@suse.com
- first packaging of jedi 0.5b5 for SUSE
